
# Changelog
All notable changes to tailbone-nationbuilder will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.1.1] - 2023-09-12
### Changed
- Add views for NationBuilder donations cache.

## [0.1.0] - 2023-09-12
### Added
- Initial version, to expose NationBuilder cache tables.
